# OrderRampMetrics


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**description** | **str** | The short description of the ramp. | [optional] 
**discount_tcb** | **float** | The discount amount for the TCB. | [optional] 
**discount_tcv** | **float** | The discount amount for the TCV. | [optional] 
**gross_tcb** | **float** | The gross TCB value before discount charges are applied. | [optional] 
**gross_tcv** | **float** | The gross TCV value before discount charges are applied. | [optional] 
**intervals** | [**List[OrderRampIntervalMetrics]**](OrderRampIntervalMetrics.md) | The ramp metrics for each ramp intervals in its timeline. | [optional] 
**name** | **str** | The name of the ramp. | [optional] 
**net_tcb** | **float** | The net TCB value after discount charges are applied. | [optional] 
**net_tcv** | **float** | The net TCV value after discount charges are applied. | [optional] 
**number** | **str** | The number of the ramp. It is automaticcally generated by the billing system. | [optional] 

## Example

```python
from zuora_sdk.models.order_ramp_metrics import OrderRampMetrics

# TODO update the JSON string below
json = "{}"
# create an instance of OrderRampMetrics from a JSON string
order_ramp_metrics_instance = OrderRampMetrics.from_json(json)
# print the JSON string representation of the object
print(OrderRampMetrics.to_json())

# convert the object into a dict
order_ramp_metrics_dict = order_ramp_metrics_instance.to_dict()
# create an instance of OrderRampMetrics from a dict
order_ramp_metrics_from_dict = OrderRampMetrics.from_dict(order_ramp_metrics_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


